/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: m-global.c                                                    *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : define global variables                                  *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: m-global.c,v 1.44 2003/01/12 00:40:22 enlf Exp $
 */

/*
   Copyright (C) 1997-2003 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

/****************************************************************************
                              H E A D E R S
****************************************************************************/


#include <stdio.h>
#include "m-defs.h"

/****************************************************************************
                              D E F I N E S 
****************************************************************************/

/* all our version constants */
const Uint32 MDC_MAJOR = XMEDCON_MAJOR;
const Uint32 MDC_MINOR = XMEDCON_MINOR;
const Uint32 MDC_MICRO = XMEDCON_MICRO;
const char  *MDC_PRGR  = XMEDCON_PRGR;
const char  *MDC_DATE  = XMEDCON_DATE;
const char  *MDC_VERSION = XMEDCON_VERSION;
const char  *MDC_LIBVERS = XMEDCON_LIBVERS;

/* fill in host endian and default write endian */
#ifdef ENLF_LITTLEENDIAN
Int8 MDC_HOST_ENDIAN = MDC_LITTLE_ENDIAN;
Int8 MDC_WRITE_ENDIAN= MDC_LITTLE_ENDIAN;
#else
Int8 MDC_HOST_ENDIAN = MDC_BIG_ENDIAN;
Int8 MDC_WRITE_ENDIAN= MDC_BIG_ENDIAN;
#endif

Int8 MDC_FILE_ENDIAN = -1;

Int8 MDC_BLOCK_MESSAGES = MDC_NO;

/* globally available variables */
char prefix[MDC_MAX_PREFIX + 1]="eNlf-"; /* 15 + '\O' */
char *mdcbasename=NULL;                  /* new base  */

char FrmtString[MDC_MAX_FRMTS][15]= {
    "Unknown      ",    /* MDC_FRMT_NONE  */
    "Raw Binary   ",    /* MDC_FRMT_RAW   */
    "Raw Ascii    ",    /* MDC_FRMT_ASCII */
    "Gif89a       ",    /* MDC_FRMT_GIF   */
    "Acr/Nema     ",    /* MDC_FRMT_ACR   */
    "INW (RUG)    ",    /* MDC_FRMT_INW   */
    "Concorde/uPET",    /* MDC_FRMT_CONC  */
    "Ecat/Matrix  ",    /* MDC_FRMT_ECAT  */
    "InterFile    ",    /* MDC_FRMT_INTF  */
    "Analyze      ",    /* MDC_FRMT_ANLZ  */
    "DICOM        ",    /* MDC_FRMT_DICM  */
    "PNG          "     /* MDC_FRMT_PNG   */
  /*"............."                       */
};

char FrmtExt[MDC_MAX_FRMTS][4]= {
    "???",    /* MDC_FRMT_NONE  */
    "bin",    /* MDC_FRMT_RAW   */
    "asc",    /* MDC_FRMT_ASCII */
    "gif",    /* MDC_FRMT_GIF   */
    "ima",    /* MDC_FRMT_ACR   */
    "im",     /* MDC_FRMT_INW   */
    "hdr",    /* MDC_FRMT_CONC  */
    "img",    /* MDC_FRMT_ECAT  */
    "h33",    /* MDC_FRMT_INTF  */
    "hdr",    /* MDC_FRMT_ANLZ  */
    "dcm",    /* MDC_FRMT_DICM  */
    "png"     /* MDC_FRMT_PNG   */ 
  /*"..."                       */
};

char mdcbufr[MDC_2KB_OFFSET+1]; /* 2KB global buffer */
char errmsg[MDC_1KB_OFFSET+1];  /* 1KB error  buffer */

float mdc_si_slope     = 1.;
float mdc_si_intercept = 0.;
float mdc_cw_center    = 0.;
float mdc_cw_width     = 0.;

/* predefined mosaic stamps layout */
Uint32 mdc_mosaic_width = 0;
Uint32 mdc_mosaic_height= 0;
Uint32 mdc_mosaic_number= 0;
Int8   mdc_mosaic_interlaced = MDC_NO;

/* crop settings */
Uint32 mdc_crop_xoffset = 0;
Uint32 mdc_crop_yoffset = 0;
Uint32 mdc_crop_width   = 0;
Uint32 mdc_crop_height  = 0;

/* flags & options */
Int8 MDC_COLOR_MAP =  MDC_MAP_NONE; /* gray color palette selected            */
Int8 MDC_ANLZ_REV  =  MDC_NO;   /* Analyze: reverse planes, rows & columns    */
Int8 MDC_ANLZ_SPM  =  MDC_NO;   /* Analyze for SPM with use of scaling factor */
Int8 MDC_ANLZ_OPTIONS = MDC_NO; /* Analyze for SPM & user supplied parameters */
Int8 MDC_DICOM_MOSAIC_ENABLED = MDC_NO;    /* DICOM: mosaic support enabled   */
Int8 MDC_DICOM_MOSAIC_FORCED  = MDC_NO;    /* DICOM: mosaic preset  forced    */
Int8 MDC_DICOM_MOSAIC_DO_INTERL = MDC_NO;  /* DICOM: mosaic forced interlaced */
Int8 MDC_DICOM_MOSAIC_FIX_VOXEL = MDC_NO;  /* DICOM: mosaic fix voxel sizes   */
Int8 MDC_DICOM_CONTRAST= MDC_NO;           /* DICOM: enable contrast window   */
Int8 MDC_DICOM_WRITE_IMPLICIT = MDC_NO;    /* DICOM: write little implicit    */
Int8 MDC_DICOM_WRITE_NOMETA = MDC_NO;      /* DICOM: write without meta header*/
Int8 MDC_FORCE_RESCALE = MDC_NO; /* apply user specified slope/intercept      */
Int8 MDC_FORCE_CONTRAST= MDC_NO; /* apply user specified window center/width  */
Int8 MDC_INFO=MDC_YES;
Int8 MDC_INTERACTIVE=MDC_NO, MDC_CONVERT=MDC_NO;
Int8 MDC_EXTRACT=MDC_NO, MDC_PIXELS=MDC_NO, MDC_NEGATIVE=MDC_NO;
Int8 MDC_QUANTIFY=MDC_NO, MDC_CALIBRATE=MDC_NO, MDC_DEBUG=MDC_NO;
Int8 MDC_GIF_OPTIONS=MDC_NO;
Int8 MDC_MAKE_GRAY=MDC_NO, MDC_DITHER_COLOR=MDC_NO;
Int8 MDC_VERBOSE=MDC_NO, MDC_RENAME=MDC_NO;
Int8 MDC_NORM_OVER_FRAMES = MDC_NO;     /* normalize over images in a frame */
                                        /* instead of all images            */
Int8 MDC_SKIP_PREVIEW = MDC_NO;         /* skip the first (preview) slice   */
Int8 MDC_IGNORE_PATH = MDC_NO;          /* ignore path in INTF data fname   */
Int8 MDC_FORCE_INT = MDC_NO;            /* force integer pixels             */
Int8 MDC_INT16_BITS_USED = 16;          /* bits to use for Int16 type       */
Int8 MDC_TRUE_GAP = MDC_NO;             /* spacing = true gap/overlap       */
Int8 MDC_ALIAS_NAME = MDC_NO;           /* use  alias name based on ID's    */
Int8 MDC_ECHO_ALIAS = MDC_NO;           /* echo alias name based on ID's    */
Int8 MDC_NO_PREFIX  = MDC_NO;           /* prevent the prefix in names      */
Int8 MDC_ACQ_PREFIX = MDC_NO;           /* use acquisition number as prefix */
Int8 MDC_SER_PREFIX = MDC_NO;           /* use series      number as prefix */
Int8 MDC_CMAP_INVERS = MDC_NO;          /* inverted colormap (gray)         */
Int8 MDC_RESLICE = MDC_NO;              /* reslice images (tra, sag, cor)   */

Int8 MDC_PATIENT_ANON = MDC_NO;         /* make patient anonymous           */
Int8 MDC_PATIENT_IDENT = MDC_NO;        /* give patient identification      */
Int8 MDC_EDIT_FI = MDC_NO;              /* edit FILEINFO struct             */
Int8 MDC_FILE_STDIN  = MDC_NO;          /* input from stdin  stream         */
Int8 MDC_FILE_STDOUT = MDC_NO;          /* output  to stdout stream         */ 
Int8 MDC_FILE_SPLIT  = MDC_NO;          /* split up file in parts           */
Int8 MDC_FILE_STACK  = MDC_NO;          /* stack up files                   */ 

Int8 MDC_FLIP_HORIZONTAL = MDC_NO;      /* flip horizontal   (x)            */
Int8 MDC_FLIP_VERTICAL   = MDC_NO;      /* flip vertical     (y)            */
Int8 MDC_SORT_REVERSE    = MDC_NO;      /* reverse   sorting                */
Int8 MDC_SORT_CINE_APPLY = MDC_NO;      /* cine apply sorting               */
Int8 MDC_SORT_CINE_UNDO  = MDC_NO;      /* cine undo  sorting               */
Int8 MDC_MAKE_SQUARE     = MDC_NO;      /* make square image                */
Int8 MDC_CROP_IMAGES     = MDC_NO;      /* crop image dimensions            */

Int8 MDC_FRMT_INPUT = MDC_FRMT_NONE;    /* format used for stdin            */ 
Int8 MDC_ECAT_SORT = MDC_ANATOMICAL;    /* ECAT sort order                  */

#if   MDC_INCLUDE_DICM                  /* fallback read format             */
Int8 MDC_FALLBACK_FRMT = MDC_FRMT_DICM;
#elif MDC_INCLUDE_ECAT
Int8 MDC_FALLBACK_FRMT = MDC_FRMT_ECAT;
#elif MDC_INCLUDE_ANLZ
Int8 MDC_FALLBACK_FRMT = MDC_FRMT_ANLZ;
#elif MDC_INCLUDE_CONC
Int8 MDC_FALLBACK_FRMT = MDC_FRMT_CONC;
#else
Int8 MDC_FALLBACK_FRMT = MDC_FRMT_NONE;
#endif

/* undocumented options, for debugging purposes only */
Int8 MDC_SIGFPE=MDC_NO;
Int8 MDC_MY_DEBUG=MDC_NO;
Int8 MDC_INFO_DB=MDC_NO;
Int8 MDC_HACK_ACR=MDC_NO;

/* XMedCon */
Int8 XMDC_MEDCON=MDC_NO;                /* is this program XMedCon !? */
Int8 XMDC_WRITE_FRMT = MDC_FRMT_RAW;    /* default format to save     */
